@@ -38,7 +38,7 @@ module.exports = [
   ['>=0.2.3 || <0.0.1', '>=0.2.3||<0.0.1'],
   ['>=0.2.3 || <0.0.1', '>=0.2.3||<0.0.1'],
   ['>=0.2.3 || <0.0.1', '>=0.2.3||<0.0.1'],
-  ['||', '||'],
+  ['||', '*'],
   ['2.x.x', '>=2.0.0 <3.0.0-0'],
   ['1.2.x', '>=1.2.0 <1.3.0-0'],
   ['1.2.x || 2.x', '>=1.2.0 <1.3.0-0||>=2.0.0 <3.0.0-0'],
@@ -79,7 +79,7 @@ module.exports = [
   ['>01.02.03', null],
   ['~1.2.3beta', '>=1.2.3-beta <1.3.0-0', { loose: true }],
   ['~1.2.3beta', null],
-  ['^ 1.2 ^ 1', '>=1.2.0 <2.0.0-0 >=1.0.0 <2.0.0-0'],
+  ['^ 1.2 ^ 1', '>=1.2.0 <2.0.0-0 >=1.0.0'],
   ['1.2 - 3.4.5', '>=1.2.0 <=3.4.5'],
   ['1.2.3 - 3.4', '>=1.2.3 <3.5.0-0'],
   ['1.2 - 3.4', '>=1.2.0 <3.5.0-0'],
@@ -87,4 +87,6 @@ module.exports = [
   ['>1.2', '>=1.3.0'],
   ['>X', '<0.0.0-0'],
   ['<X', '<0.0.0-0'],
+  ['<x <* || >* 2.x', '<0.0.0-0'],
+  ['>x 2.x || * || <x', '*'],
 ]
